"""{{ project_name_title }} - Node 项目

{{ project_description }}
"""

from sdwk import Component, Data, Input, InputType, Output, OutputType

__version__ = "{{ project_version }}"

__all__ = [
    "Component",
    "Data",
    "Input",
    "InputType",
    "Output",
    "OutputType",
]
